@@ -205,6 +205,9 @@ class Database(object):
 
         try:
             Head.visit(visit_function)
+            # Copy top level attributes
+            for key in list(Head.attrs.keys()):
+                Origin.attrs[key] = Head.attrs[key]
 
         finally:
             Origin.close()
