@@ -155,6 +155,7 @@ def test_attrs():
     # Check that groups can have attrs
     db.attr_set(TESTGROUP1, "name", TESTGROUP1)
     assert db.attr_value(TESTGROUP1, "name") == TESTGROUP1
+    db.attr_set("/", "fname", TESTDATA)
     return 
 
 def test_fields():
@@ -175,6 +176,7 @@ def test_shard():
     assert np.allclose(db.dset_value(TESTDATA_NAME3), db_shard.dset_value(TESTDATA_NAME3))
     # Check the compression
     assert db_shard.dset_compression(TESTDATA_NAME3) == "gzip"
+    assert db_shard.attr_value("/", "fname") == TESTDATA
 
     # Point to a different group
     db = Database(TESTDATA, TESTGROUP1)
@@ -196,6 +198,7 @@ def test_shard():
     db.shard(TESTSHARD2, [TESTDATA_NAME4], compression="gzip")
     # Point to that database
     db_shard = Database(TESTSHARD2)
+    assert db_shard.attr_value("/", "fname") == TESTDATA
     assert db_shard.exists(TESTDATA_NAME4)
     return
 
@@ -217,6 +220,7 @@ def test_merge():
     assert db_merge.attr_exists(TESTDATA_NAME3, "max")
     assert db_merge.attr_exists(TESTDATA_NAME3, "sum")
     assert db_merge.attr_value(TESTGROUP1, "name") == TESTGROUP1
+    assert db_merge.attr_value("/", "fname") == TESTDATA
 
     return
 
@@ -274,6 +278,7 @@ def test_rebase():
     assert db.attr_exists(TESTDATA_NAME3, "max")
     assert db.attr_exists(TESTDATA_NAME3, "sum")
     assert db.attr_value(TESTGROUP1, "name") == TESTGROUP1
+    assert db.attr_value("/", "fname") == TESTDATA
     assert db.size_on_disk() < initial_size
 
     return
